"""
Driving a 16x2 alfanumeric LCD display through an MC23017 I2C I/O expander

See more details at: https://www.cspista.hu/2022/h2022_07.pdf and
https://learn.adafruit.com/character-lcds/python-circuitpython
"""

import time
import board
import busio
from digitalio import *
import adafruit_character_lcd.character_lcd as characterlcd
from adafruit_mcp230xx.mcp23017 import MCP23017
 
i2c = busio.I2C(board.SCL, board.SDA)            # Initialize the I2C bus:
mcp = MCP23017(i2c, address=0x20, reset=True)    # MCP23017
# LCD is connected to the GPIOB port of the MCP23017 IC:
lcd_rs = mcp.get_pin(8)    # B0
lcd_en = mcp.get_pin(9)    # B1
lcd_d7 = mcp.get_pin(15)   # B7
lcd_d6 = mcp.get_pin(14)   # B6
lcd_d5 = mcp.get_pin(13)   # B5
lcd_d4 = mcp.get_pin(12)   # B4
lcd_backlight = mcp.get_pin(10) # B2

lcd = characterlcd.Character_LCD_Mono(
    lcd_rs, lcd_en, lcd_d4, lcd_d5, lcd_d6, lcd_d7, 16, 2, lcd_backlight
)
 
lcd.backlight = True               # Turn backlight on
lcd.clear()                        # Clear screen
lcd.message = "CircuitPython\nLCD display"
