"""
   This program sends a GET request to the OpenWeatherMap API using the requests
   module, and it includes the location and units parameters in the request.
   The API returns a JSON object containing the weather data, from which we
   extract the relevant data (temp, humidity, pressure). Then we prepare a 
   formatted text from these data and send it to the axiliary LCD display
   through the COM5 serial port.

   Remember to replace "YOUR_API_KEY_HERE" with your actual API key. You can sign up
   for a free API key at https://home.openweathermap.org/users/sign_up .

   Make sure that you have the requests library installed. You can install it by 
   running 'pip install requests' in your command line.
"""

import requests

import json
import io
import serial
import time

# configure the serial port
ser = serial.Serial(
    port='COM5',
    baudrate=9600,
    parity=serial.PARITY_NONE,
    stopbits=serial.STOPBITS_ONE,
    bytesize=serial.EIGHTBITS,
    timeout=1
)

# Set the API endpoint and your API key
API_ENDPOINT = "https://api.openweathermap.org/data/2.5/weather"
API_KEY = "YOUR_API_KEY_HERE"

# Set the location parameters
LOCATION_NAME = "Debrecen, Hungary"
LOCATION_LAT = "47.53"
LOCATION_LON = "21.62"

# Set the units
UNITS = "metric"

# Set up the request parameters
params = {
    "q": LOCATION_NAME,
    "lat": LOCATION_LAT,
    "lon": LOCATION_LON,
    "units": UNITS,
    "appid": API_KEY
}

# Make the request
response = requests.get(API_ENDPOINT, params=params)
#print(response.json())
dataJSON = json.loads(response.text)
print(json.dumps(dataJSON,indent=4))
temp = float(dataJSON['main']['temp'])
humidity = int(dataJSON['main']['humidity'])
pressure = int(dataJSON['main']['pressure'])
s=io.StringIO("")
print("Debrecen {0:.1f} C#{1} hPa {2}%\r\n".format(temp,pressure,humidity),file=s)
print(s.getvalue())
ser.write(s.getvalue().encode())

s.close()

